﻿using System.Windows;
using Abt.Controls.SciChart.Visuals;

namespace WpfApplication17
{
    /// <summary>
    /// Make your viewmodels to inject into implement this interface. If not, it won't work
    /// </summary>
    public interface IInjectSciChartController
    {
        ISciChartController SciChartController { get; set; }
    }

    /// <summary>
    /// Use this attached property to pass the SciChartSurface to a ViewModel as ISciChartController interface 
    /// </summary>
    public class Injector
    {
        public static readonly DependencyProperty PassSurfaceToViewModelProperty = DependencyProperty.RegisterAttached(
            "PassSurfaceToViewModel", typeof(bool), typeof(Injector), new PropertyMetadata(default(bool), OnPassSurfaceToViewModelPropertyChanged));

        private static void OnPassSurfaceToViewModelPropertyChanged(DependencyObject d, DependencyPropertyChangedEventArgs e)
        {
            var scs = d as SciChartSurface;
            if (scs == null || ((bool)e.NewValue) == false) return;

            scs.DataContextChanged += (s, arg) => UpdateProperty(scs, scs.DataContext as IInjectSciChartController);

            UpdateProperty(scs, scs.DataContext as IInjectSciChartController);
        }

        private static void UpdateProperty(SciChartSurface scs, IInjectSciChartController vm)
        {
            if (vm == null) return;
            vm.SciChartController = scs;
        }

        public static void SetPassSurfaceToViewModel(DependencyObject element, ISuspendable value)
        {
            element.SetValue(PassSurfaceToViewModelProperty, value);
        }

        public static bool GetPassSurfaceToViewModel(DependencyObject element)
        {
            return (bool)element.GetValue(PassSurfaceToViewModelProperty);
        }
    }
}