﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Diagnostics;
using System.Linq;
using System.Text;
using Abt.Controls.SciChart.Visuals;

namespace WpfApplication17
{
    /// <summary>
    /// Implement your viewmodel and implement IInjectSciChartController, otherwise the passing of ISciChartController to viewmodel won't work
    /// </summary>
    public class MainViewModel : INotifyPropertyChanged, IInjectSciChartController
    {
        private ISciChartController _scs;
        public event PropertyChangedEventHandler PropertyChanged;

        public ISciChartController SciChartController
        {
            get { return _scs; }
            set
            {
                _scs = value;

                if (_scs != null)
                {
                    // You now have a SciChartSurface instance passed in as ISciChartController and you can suspend / resume updates as you wish! 
                    Debug.WriteLine("Received a SciChartSurface instance!");
                    Debugger.Break();
                }
            }
        }

        protected virtual void OnPropertyChanged(string propertyName)
        {
            var handler = PropertyChanged;
            if (handler != null) handler(this, new PropertyChangedEventArgs(propertyName));
        }
    }
}
